==> haskell-vault-0.3.1.5-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vault
version:              0.3.1.5
visibility:           public
id:                   vault-0.3.1.5-8GbzBYBhlE43J0ce7wkjJO
key:                  vault-0.3.1.5-8GbzBYBhlE43J0ce7wkjJO
license:              BSD-3-Clause
copyright:            (c) Heinrich Apfelmus 2011-2013
maintainer:           Heinrich Apfelmus <apfelmus at quantentunnel de>
author:               Heinrich Apfelmus, Elliott Hird
homepage:             https://github.com/HeinrichApfelmus/vault
synopsis:             a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.

    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.

    Also provided is a /locker/ type, representing a store for a single element.

category:             Data
abi:                  b0d350ae88f88dcfe5ed9487480044f8
exposed:              True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict

import-dirs:          /usr/lib/ghc-9.0.2/site-local/vault-0.3.1.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vault-0.3.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vault
hs-libraries:         HSvault-0.3.1.5-8GbzBYBhlE43J0ce7wkjJO
depends:
    base-4.15.1.0 containers-0.6.4.1
    hashable-1.4.1.0-DXpj0ho9mwSB6ue30MIccy
    unordered-containers-0.2.19.1-8VYAOBvAPnuAGZDvxcTgvW

haddock-interfaces:   /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html:         /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vault-0.3.1.5-125-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vault
version:              0.3.1.5
visibility:           public
id:                   vault-0.3.1.5-DxDUDjLC3ttLap0odij5MH
key:                  vault-0.3.1.5-DxDUDjLC3ttLap0odij5MH
license:              BSD-3-Clause
copyright:            (c) Heinrich Apfelmus 2011-2013
maintainer:           Heinrich Apfelmus <apfelmus at quantentunnel de>
author:               Heinrich Apfelmus, Elliott Hird
homepage:             https://github.com/HeinrichApfelmus/vault
synopsis:             a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.

    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.

    Also provided is a /locker/ type, representing a store for a single element.

category:             Data
abi:                  fdbf7d4f45c47d68be0f319564beb82e
exposed:              True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict

import-dirs:          /usr/lib/ghc-9.0.2/site-local/vault-0.3.1.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vault-0.3.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vault
hs-libraries:         HSvault-0.3.1.5-DxDUDjLC3ttLap0odij5MH
depends:
    base-4.15.1.0 containers-0.6.4.1
    hashable-1.4.1.0-DXpj0ho9mwSB6ue30MIccy
    unordered-containers-0.2.19.1-1oz2vTo8QZe9pPW8EMafVJ

haddock-interfaces:   /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html:         /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
